==> netw-ib-ox-ag_5.34.0.orig.tar.gz: netw-ib-ox-ag-5.34.0/src/netwib-src/src/netwib/sys/kbdbuf.c <==
/*
                                  NETWIB
                             Network library
                Copyright(c) 1999-2006 Laurent Constantin
                                  -----

  Main server    : http://www.laurentconstantin.com/
  Backup servers : http://go.to/laurentconstantin/
                   http://laurentconstantin.est-la.com/
                   http://laurentconstantin.free.fr/
                   http://membres.lycos.fr/lauconstantin/
  [my current email address is on the web servers]

                                  -----
  This file is part of Netwib.

  Netwib is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.

  Netwib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <netwib/inc/maininc.h>

/*-------------------------------------------------------------*/
netwib_err netwib_buf_append_kbd(netwib_constbuf *pmessage,
                                 netwib_constbuf *pdefaulttext,
                                 netwib_buf *pbuf)
{
  netwib_er(netwib_priv_kbd_buf_append(pmessage, pdefaulttext,
                                       NETWIB_TRUE, ':', NETWIB_TRUE,
                                       pbuf));
  return(NETWIB_ERR_OK);
}

/*-------------------------------------------------------------*/
netwib_err netwib_buf_append_passwd(netwib_constbuf *pmessage,
                                    netwib_constbuf *pdefaulttext,
                                    netwib_buf *pbuf)
{
  netwib_er(netwib_priv_kbd_buf_append(pmessage, pdefaulttext,
                                       NETWIB_FALSE, ':', NETWIB_TRUE,
                                       pbuf));
  return(NETWIB_ERR_OK);
}

==> netw-ib-ox-ag_5.36.0.orig.tar.gz: netw-ib-ox-ag-5.36.0/src/netwib-src/src/netwib/sys/kbdbuf.c <==
/*
                                  NETWIB
                             Network library
                Copyright(c) 1999-2008 Laurent Constantin
                                  -----

  Main server   : http://www.laurentconstantin.com/
  Backup server : http://laurentconstantin.free.fr/
  [my current email address is on the web servers]

                                  -----
  This file is part of Netwib.

  Netwib is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.

  Netwib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <netwib/inc/maininc.h>

/*-------------------------------------------------------------*/
netwib_err netwib_buf_append_kbd(netwib_constbuf *pmessage,
                                 netwib_constbuf *pdefaulttext,
                                 netwib_buf *pbuf)
{
  netwib_er(netwib_priv_kbd_buf_append(pmessage, pdefaulttext,
                                       NETWIB_TRUE, ':', NETWIB_TRUE,
                                       pbuf));
  return(NETWIB_ERR_OK);
}

/*-------------------------------------------------------------*/
netwib_err netwib_buf_append_password(netwib_constbuf *pmessage,
                                      netwib_constbuf *pdefaulttext,
                                      netwib_buf *pbuf)
{
  netwib_er(netwib_priv_kbd_buf_append(pmessage, pdefaulttext,
                                       NETWIB_FALSE, ':', NETWIB_TRUE,
                                       pbuf));

  /* suppose this buffer is sensitive */
  pbuf->flags |= NETWIB_BUF_FLAGS_SENSITIVE;

  return(NETWIB_ERR_OK);
}
